@@ -1,7 +1,16 @@
-# $Author: ddumont $
-# $Date: 2008-04-13 18:37:11 +0200 (dim, 13 avr 2008) $
+# 
+# This file is part of Config-Model-Itself
+# 
+# This software is Copyright (c) 2010 by Dominique Dumont.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+# 
+# $Author$
+# $Date$
 # $Name: not supported by cvs2svn $
-# $Revision: 602 $
+# $Revision$
 
 #    Copyright (c) 2007 Dominique Dumont.
 #
@@ -31,6 +40,7 @@
        => {
 	   type => 'hash',
 	   index_type => 'string' , 
+	   ordered => 1,
 	   cargo => { type => 'node',
 		      config_class_name => 'Itself::Class' ,
 		    },
